import sys
import logging
from pprint import pprint
import json
from pathlib import Path
import fileinput

import xmltodict
import argparse


def extract_prefixes (d):
    return { k.split(':')[1]: d[k] for k in d.keys() if k.startswith("@xmlns:") }

def removePrefixes (o, prefixes):
    if not isinstance(o, dict): return    
    replacements = []
    for k,v in o.items():
        if isinstance(v, dict):
            removePrefixes(v, prefixes)
        if isinstance(v, list):
            for i in v:
                removePrefixes(i, prefixes)
        if ":" in k:
            prefix = k.split(':')[0]
            if (prefix) in prefixes:
                new_key = k.split(':')[1]
                replacements.append( (k, new_key) )
    for r in replacements:
        o[r[1]] = o.pop(r[0])

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument('-v', '--verbose', action='count', help='Verbose logging (can be specified multiple times)')
    parser.add_argument('-i', '--input', type=argparse.FileType('r'), default=sys.stdin, help="Path to input file (if absent, stdin is used)")
    args = parser.parse_args()

    match args.verbose:
        case v if v and v >= 2:
            logging.basicConfig(level=logging.DEBUG)
        case 1:
            logging.basicConfig(level=logging.INFO)
        case _:
            logging.basicConfig(level=logging.WARNING)

    logging.debug(f"Arguments: {args}")

    s = args.input.read()
    args.input.close()

    logging.debug(s)
    # d = xmltodict.parse(s,
    #                     force_list=('AssociatedObject',)
    #                     )['HI1Message']

    d = xmltodict.parse(s,
                        force_list=('AssociatedObject',)
                        )['HI1Message']

    # prefixes = extract_prefixes(d)
    # removePrefixes(d, prefixes)

    print(json.dumps(d, indent=2))
